summaryrefslogtreecommitdiffstats
path: root/ctdb/tests/onnode
diff options
context:
space:
mode:
authorMartin Schwenke <martin@meltin.net>2011-07-07 16:17:52 +1000
committerMartin Schwenke <martin@meltin.net>2011-08-03 15:55:35 +1000
commit7cec7807e11f433d781835975a0cfddb25b66585 (patch)
tree1985194d7bfdd2d87bd98f4551f18062127b7619 /ctdb/tests/onnode
parent8006aec7b1d5687fb8776405c5e5ff031899107a (diff)
downloadsamba-7cec7807e11f433d781835975a0cfddb25b66585.tar.gz
samba-7cec7807e11f433d781835975a0cfddb25b66585.tar.xz
samba-7cec7807e11f433d781835975a0cfddb25b66585.zip
Tests: eventscripts and onnode tests use stubs/ subdirectory instead of bin/.
This sets up a more useful convention and avoids future .gitignore problems. Resolved conflict while cherry-picking this: Don't take the eventscripts files for this branch. We'll put them elsewhere. Signed-off-by: Martin Schwenke <martin@meltin.net> (This used to be ctdb commit a9879e37d4e3bb714ef6c0c4144c6949daec0b53)
Diffstat (limited to 'ctdb/tests/onnode')
-rw-r--r--ctdb/tests/onnode/README4
-rw-r--r--ctdb/tests/onnode/common.sh10
-rwxr-xr-xctdb/tests/onnode/stubs/ctdb (renamed from ctdb/tests/onnode/bin/ctdb)0
-rwxr-xr-xctdb/tests/onnode/stubs/onnode-buggy-001 (renamed from ctdb/tests/onnode/bin/onnode-buggy-001)0
-rwxr-xr-xctdb/tests/onnode/stubs/ssh (renamed from ctdb/tests/onnode/bin/ssh)0
5 files changed, 7 insertions, 7 deletions
diff --git a/ctdb/tests/onnode/README b/ctdb/tests/onnode/README
index 1bbf7af5a5..58943d3845 100644
--- a/ctdb/tests/onnode/README
+++ b/ctdb/tests/onnode/README
@@ -17,7 +17,7 @@ Examples:
* ONNODE=onnode-buggy-001 ./run_tests.sh -s
- Run against bin/onnode-buggy-001 instead of default onnode version.
+ Run against stubs/onnode-buggy-001 instead of default onnode version.
Add more buggy versions of onnode to this directory as bugs are
fixed to enable test validation using this feature.
@@ -26,7 +26,7 @@ Examples:
Run only the specified tests.
-* ONNODE="bash -x bin/onnode-buggy-001" ./run_tests.sh ./0090.sh
+* ONNODE="bash -x stubs/onnode-buggy-001" ./run_tests.sh ./0090.sh
ONNODE="bash -x ../../tools/onnode" ./run_tests.sh ./0090.sh
Debug the specified test or test failure. The test will fail
diff --git a/ctdb/tests/onnode/bin/ctdb b/ctdb/tests/onnode/stubs/ctdb
index e420d25e02..e420d25e02 100755
--- a/ctdb/tests/onnode/bin/ctdb
+++ b/ctdb/tests/onnode/stubs/ctdb
diff --git a/ctdb/tests/onnode/bin/onnode-buggy-001 b/ctdb/tests/onnode/stubs/onnode-buggy-001
index 77a1207d6c..77a1207d6c 100755
--- a/ctdb/tests/onnode/bin/onnode-buggy-001
+++ b/ctdb/tests/onnode/stubs/onnode-buggy-001
diff --git a/ctdb/tests/onnode/bin/ssh b/ctdb/tests/onnode/stubs/ssh
index 7be778f1b9..7be778f1b9 100755
--- a/ctdb/tests/onnode/bin/ssh
+++ b/ctdb/tests/onnode/stubs/ssh
diff --git a/ctdb/tests/onnode/common.sh b/ctdb/tests/onnode/common.sh
index e4cca32162..f920bc398a 100644
--- a/ctdb/tests/onnode/common.sh
+++ b/ctdb/tests/onnode/common.sh
@@ -6,10 +6,10 @@ unset CTDB_NODES_SOCKETS
# Default to just "onnode".
: ${ONNODE:=onnode}
-# Augment PATH with relevant bin/ directories.
+# Augment PATH with relevant stubs/ directories.
-if [ -d "${ONNODE_TESTS_DIR}/bin" ] ; then
- PATH="${ONNODE_TESTS_DIR}/bin:$PATH"
+if [ -d "${ONNODE_TESTS_DIR}/stubs" ] ; then
+ PATH="${ONNODE_TESTS_DIR}/stubs:$PATH"
fi
export ONNODE_TESTCASE_DIR=$(dirname "$0")
@@ -17,8 +17,8 @@ if [ $(basename "$ONNODE_TESTCASE_DIR") = "onnode" ] ; then
# Just a test script, no testcase subdirectory.
ONNODE_TESTCASE_DIR="$ONNODE_TESTS_DIR"
else
- if [ -d "${ONNODE_TESTCASE_DIR}/bin" ] ; then
- PATH="${ONNODE_TESTCASE_DIR}/bin:$PATH"
+ if [ -d "${ONNODE_TESTCASE_DIR}/stubs" ] ; then
+ PATH="${ONNODE_TESTCASE_DIR}/stubs:$PATH"
fi
fi